MemoryServiceClient

Struct MemoryServiceClient 

pub struct MemoryServiceClient<T> { /* private fields */ }

Implementations

Source

impl MemoryServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> MemoryServiceClient<T>
where T: GrpcService<Body>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> MemoryServiceClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>, <T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn upsert_memory_record( &mut self, request: impl IntoRequest<UpsertMemoryRecordRequest>, ) -> Result<Response<UpsertMemoryRecordReply>, Status>

pub async fn batch_upsert_memory_records( &mut self, request: impl IntoRequest<BatchUpsertMemoryRecordsRequest>, ) -> Result<Response<BatchUpsertMemoryRecordsReply>, Status>

pub async fn recall( &mut self, request: impl IntoRequest<RecallRequest>, ) -> Result<Response<RecallReply>, Status>

pub async fn compact( &mut self, request: impl IntoRequest<CompactRequest>, ) -> Result<Response<CompactReply>, Status>

pub async fn snapshot( &mut self, request: impl IntoRequest<SnapshotRequest>, ) -> Result<Response<SnapshotReply>, Status>

pub async fn delete( &mut self, request: impl IntoRequest<DeleteRequest>, ) -> Result<Response<DeleteReply>, Status>

pub async fn archive( &mut self, request: impl IntoRequest<ArchiveRequest>, ) -> Result<Response<ArchiveReply>, Status>

pub async fn suppress( &mut self, request: impl IntoRequest<SuppressRequest>, ) -> Result<Response<SuppressReply>, Status>

pub async fn recover( &mut self, request: impl IntoRequest<RecoverRequest>, ) -> Result<Response<RecoverReply>, Status>

pub async fn stats( &mut self, request: impl IntoRequest<StoreStatsRequest>, ) -> Result<Response<StoreStatsReply>, Status>

pub async fn integrity_check( &mut self, request: impl IntoRequest<IntegrityCheckRequest>, ) -> Result<Response<IntegrityCheckReply>, Status>

pub async fn repair( &mut self, request: impl IntoRequest<RepairRequest>, ) -> Result<Response<RepairReply>, Status>

pub async fn list_traces( &mut self, request: impl IntoRequest<ListTracesRequest>, ) -> Result<Response<ListTracesReply>, Status>

pub async fn get_trace( &mut self, request: impl IntoRequest<GetTraceRequest>, ) -> Result<Response<OperationTrace>, Status>

pub async fn export( &mut self, request: impl IntoRequest<ExportRequest>, ) -> Result<Response<ExportReply>, Status>

pub async fn import( &mut self, request: impl IntoRequest<ImportRequest>, ) -> Result<Response<ImportReply>, Status>