EngineTuningInfo

Struct EngineTuningInfo 

pub struct EngineTuningInfo {
    pub recall_scorer_kind: i32,
    pub recall_scoring_profile: i32,
    pub embedding_provider_kind: i32,
    pub embedding_dimensions: u64,
    pub compaction_summarize_after_record_count: u64,
    pub compaction_cold_archive_after_days: u32,
    pub compaction_cold_archive_importance_threshold_per_mille: u32,
    pub recall_planning_profile: Option<String>,
    pub graph_expansion_max_hops: u32,
    pub recall_policy_profile: i32,
}

Fields

recall_scorer_kind: i32recall_scoring_profile: i32embedding_provider_kind: i32embedding_dimensions: u64compaction_summarize_after_record_count: u64compaction_cold_archive_after_days: u32compaction_cold_archive_importance_threshold_per_mille: u32recall_planning_profile: Option<String>graph_expansion_max_hops: u32recall_policy_profile: i32

Implementations

Source

impl EngineTuningInfo

pub fn recall_scorer_kind(&self) -> RecallScorerKind

Returns the enum value of recall_scorer_kind, or the default if the field is set to an invalid enum value.

pub fn set_recall_scorer_kind(&mut self, value: RecallScorerKind)

Sets recall_scorer_kind to the provided enum value.

pub fn recall_scoring_profile(&self) -> RecallScoringProfile

Returns the enum value of recall_scoring_profile, or the default if the field is set to an invalid enum value.

pub fn set_recall_scoring_profile(&mut self, value: RecallScoringProfile)

Sets recall_scoring_profile to the provided enum value.

pub fn embedding_provider_kind(&self) -> EmbeddingProviderKind

Returns the enum value of embedding_provider_kind, or the default if the field is set to an invalid enum value.

pub fn set_embedding_provider_kind(&mut self, value: EmbeddingProviderKind)

Sets embedding_provider_kind to the provided enum value.

pub fn recall_planning_profile(&self) -> &str

Returns the value of recall_planning_profile, or the default value if recall_planning_profile is unset.

pub fn recall_policy_profile(&self) -> RecallPolicyProfile

Returns the enum value of recall_policy_profile, or the default if the field is set to an invalid enum value.

pub fn set_recall_policy_profile(&mut self, value: RecallPolicyProfile)

Sets recall_policy_profile to the provided enum value.