pub struct EpisodeContext {Show 20 fields
pub schema_version: u32,
pub episode_id: String,
pub summary: Option<String>,
pub continuity_state: String,
pub actor_ids: Vec<String>,
pub goal: Option<String>,
pub outcome: Option<String>,
pub started_at_unix_ms: Option<u64>,
pub ended_at_unix_ms: Option<u64>,
pub last_active_unix_ms: Option<u64>,
pub recurrence_key: Option<String>,
pub recurrence_interval_ms: Option<u64>,
pub boundary_label: Option<String>,
pub previous_record_id: Option<String>,
pub next_record_id: Option<String>,
pub causal_record_ids: Vec<String>,
pub related_record_ids: Vec<String>,
pub linked_artifact_uris: Vec<String>,
pub salience: Option<EpisodeSalience>,
pub affective: Option<AffectiveAnnotation>,
}Fields
schema_version: u32episode_id: Stringsummary: Option<String>continuity_state: Stringactor_ids: Vec<String>goal: Option<String>outcome: Option<String>started_at_unix_ms: Option<u64>ended_at_unix_ms: Option<u64>last_active_unix_ms: Option<u64>recurrence_key: Option<String>recurrence_interval_ms: Option<u64>boundary_label: Option<String>previous_record_id: Option<String>next_record_id: Option<String>causal_record_ids: Vec<String>linked_artifact_uris: Vec<String>salience: Option<EpisodeSalience>affective: Option<AffectiveAnnotation>Implementations
Sourceimpl EpisodeContext
impl EpisodeContext
Sourcepub fn summary(&self) -> &str
pub fn summary(&self) -> &str
Returns the value of summary, or the default value if summary is unset.
Sourcepub fn outcome(&self) -> &str
pub fn outcome(&self) -> &str
Returns the value of outcome, or the default value if outcome is unset.
Sourcepub fn started_at_unix_ms(&self) -> u64
pub fn started_at_unix_ms(&self) -> u64
Returns the value of started_at_unix_ms, or the default value if started_at_unix_ms is unset.
Sourcepub fn ended_at_unix_ms(&self) -> u64
pub fn ended_at_unix_ms(&self) -> u64
Returns the value of ended_at_unix_ms, or the default value if ended_at_unix_ms is unset.
Sourcepub fn last_active_unix_ms(&self) -> u64
pub fn last_active_unix_ms(&self) -> u64
Returns the value of last_active_unix_ms, or the default value if last_active_unix_ms is unset.
Sourcepub fn previous_record_id(&self) -> &str
pub fn previous_record_id(&self) -> &str
Returns the value of previous_record_id, or the default value if previous_record_id is unset.
Sourcepub fn next_record_id(&self) -> &str
pub fn next_record_id(&self) -> &str
Returns the value of next_record_id, or the default value if next_record_id is unset.
Sourcepub fn recurrence_key(&self) -> &str
pub fn recurrence_key(&self) -> &str
Returns the value of recurrence_key, or the default value if recurrence_key is unset.
Sourcepub fn recurrence_interval_ms(&self) -> u64
pub fn recurrence_interval_ms(&self) -> u64
Returns the value of recurrence_interval_ms, or the default value if recurrence_interval_ms is unset.
Sourcepub fn boundary_label(&self) -> &str
pub fn boundary_label(&self) -> &str
Returns the value of boundary_label, or the default value if boundary_label is unset.