pub struct GraphInspectionReply {
pub generated_at_unix_ms: u64,
pub total_records_scanned: u64,
pub nodes: Vec<GraphInspectionNode>,
pub edges: Vec<GraphInspectionEdge>,
pub truncated: bool,
}Fields
generated_at_unix_ms: u64total_records_scanned: u64nodes: Vec<GraphInspectionNode>edges: Vec<GraphInspectionEdge>truncated: boolTrait Implementations
Sourceimpl Clone for GraphInspectionReply
impl Clone for GraphInspectionReply
Sourcefn clone(&self) -> GraphInspectionReply
fn clone(&self) -> GraphInspectionReply
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphInspectionReply
impl Debug for GraphInspectionReply
Sourceimpl Default for GraphInspectionReply
impl Default for GraphInspectionReply
Sourceimpl Message for GraphInspectionReply
impl Message for GraphInspectionReply
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GraphInspectionReply
impl PartialEq for GraphInspectionReply
Sourcefn eq(&self, other: &GraphInspectionReply) -> bool
fn eq(&self, other: &GraphInspectionReply) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GraphInspectionReply