pub struct ImportReply {
pub mode: i32,
pub dry_run: bool,
pub applied: bool,
pub compatible_package: bool,
pub snapshot_id: String,
pub package_version: u32,
pub validated_records: u64,
pub imported_records: u64,
pub skipped_records: u64,
pub replaced_existing: bool,
pub failed_records: Vec<ImportFailure>,
}Fields
mode: i32dry_run: boolapplied: boolcompatible_package: boolsnapshot_id: Stringpackage_version: u32validated_records: u64imported_records: u64skipped_records: u64replaced_existing: boolfailed_records: Vec<ImportFailure>Implementations
Sourceimpl ImportReply
impl ImportReply
Sourcepub fn mode(&self) -> ImportMode
pub fn mode(&self) -> ImportMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: ImportMode)
pub fn set_mode(&mut self, value: ImportMode)
Sets mode to the provided enum value.