pub struct IntegrityCheckReply {
pub generated_at_unix_ms: u64,
pub healthy: bool,
pub scanned_records: u64,
pub scanned_idempotency_keys: u64,
pub stale_idempotency_keys: u64,
pub missing_idempotency_keys: u64,
pub duplicate_active_records: u64,
}Fields
generated_at_unix_ms: u64healthy: boolscanned_records: u64scanned_idempotency_keys: u64stale_idempotency_keys: u64missing_idempotency_keys: u64duplicate_active_records: u64Trait Implementations
Sourceimpl Clone for IntegrityCheckReply
impl Clone for IntegrityCheckReply
Sourcefn clone(&self) -> IntegrityCheckReply
fn clone(&self) -> IntegrityCheckReply
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IntegrityCheckReply
impl Debug for IntegrityCheckReply
Sourceimpl Default for IntegrityCheckReply
impl Default for IntegrityCheckReply
Sourceimpl Hash for IntegrityCheckReply
impl Hash for IntegrityCheckReply
Sourceimpl Message for IntegrityCheckReply
impl Message for IntegrityCheckReply
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for IntegrityCheckReply
impl PartialEq for IntegrityCheckReply
Sourcefn eq(&self, other: &IntegrityCheckReply) -> bool
fn eq(&self, other: &IntegrityCheckReply) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for IntegrityCheckReply
impl Eq for IntegrityCheckReply
impl StructuralPartialEq for IntegrityCheckReply