pub struct ListTracesRequest {
pub tenant_id: Option<String>,
pub namespace: Option<String>,
pub limit: Option<u32>,
pub operation: i32,
pub status: i32,
pub before_started_at_unix_ms: Option<u64>,
}Fields
tenant_id: Option<String>namespace: Option<String>limit: Option<u32>operation: i32status: i32before_started_at_unix_ms: Option<u64>Implementations
Sourceimpl ListTracesRequest
impl ListTracesRequest
Sourcepub fn tenant_id(&self) -> &str
pub fn tenant_id(&self) -> &str
Returns the value of tenant_id, or the default value if tenant_id is unset.
Sourcepub fn namespace(&self) -> &str
pub fn namespace(&self) -> &str
Returns the value of namespace, or the default value if namespace is unset.
Sourcepub fn operation(&self) -> TraceOperationKind
pub fn operation(&self) -> TraceOperationKind
Returns the enum value of operation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operation(&mut self, value: TraceOperationKind)
pub fn set_operation(&mut self, value: TraceOperationKind)
Sets operation to the provided enum value.
Sourcepub fn status(&self) -> TraceStatus
pub fn status(&self) -> TraceStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TraceStatus)
pub fn set_status(&mut self, value: TraceStatus)
Sets status to the provided enum value.
Sourcepub fn before_started_at_unix_ms(&self) -> u64
pub fn before_started_at_unix_ms(&self) -> u64
Returns the value of before_started_at_unix_ms, or the default value if before_started_at_unix_ms is unset.