pub struct MaintenanceStats {
pub duplicate_candidate_groups: u64,
pub duplicate_candidate_records: u64,
pub tombstoned_records: u64,
pub expired_records: u64,
pub stale_idempotency_keys: u64,
pub historical_records: u64,
pub superseded_records: u64,
pub lineage_links: u64,
}Fields
duplicate_candidate_groups: u64duplicate_candidate_records: u64tombstoned_records: u64expired_records: u64stale_idempotency_keys: u64historical_records: u64superseded_records: u64lineage_links: u64Trait Implementations
Sourceimpl Clone for MaintenanceStats
impl Clone for MaintenanceStats
Sourcefn clone(&self) -> MaintenanceStats
fn clone(&self) -> MaintenanceStats
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MaintenanceStats
impl Debug for MaintenanceStats
Sourceimpl Default for MaintenanceStats
impl Default for MaintenanceStats
Sourceimpl Hash for MaintenanceStats
impl Hash for MaintenanceStats
Sourceimpl Message for MaintenanceStats
impl Message for MaintenanceStats
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MaintenanceStats
impl PartialEq for MaintenanceStats
impl Copy for MaintenanceStats
impl Eq for MaintenanceStats
impl StructuralPartialEq for MaintenanceStats