pub struct NamespaceStats {
pub tenant_id: String,
pub namespace: String,
pub active_records: u64,
pub archived_records: u64,
pub deleted_records: u64,
pub suppressed_records: u64,
pub pinned_records: u64,
}Fields
tenant_id: Stringnamespace: Stringactive_records: u64archived_records: u64deleted_records: u64suppressed_records: u64pinned_records: u64Trait Implementations
Sourceimpl Clone for NamespaceStats
impl Clone for NamespaceStats
Sourcefn clone(&self) -> NamespaceStats
fn clone(&self) -> NamespaceStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NamespaceStats
impl Debug for NamespaceStats
Sourceimpl Default for NamespaceStats
impl Default for NamespaceStats
Sourceimpl Hash for NamespaceStats
impl Hash for NamespaceStats
Sourceimpl Message for NamespaceStats
impl Message for NamespaceStats
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NamespaceStats
impl PartialEq for NamespaceStats
Sourcefn eq(&self, other: &NamespaceStats) -> bool
fn eq(&self, other: &NamespaceStats) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for NamespaceStats
impl StructuralPartialEq for NamespaceStats