pub struct OperationTrace {Show 18 fields
pub trace_id: String,
pub correlation_id: String,
pub operation: i32,
pub transport: String,
pub backend: Option<String>,
pub admission_class: Option<String>,
pub tenant_id: Option<String>,
pub namespace: Option<String>,
pub principal: Option<String>,
pub store_span_id: Option<String>,
pub planning_trace_id: Option<String>,
pub started_at_unix_ms: u64,
pub completed_at_unix_ms: u64,
pub latency_ms: u64,
pub status: i32,
pub status_message: Option<String>,
pub summary: Option<OperationTraceSummary>,
pub recall_explanation: Option<RecallExplanation>,
}Fields
trace_id: Stringcorrelation_id: Stringoperation: i32transport: Stringbackend: Option<String>admission_class: Option<String>tenant_id: Option<String>namespace: Option<String>principal: Option<String>store_span_id: Option<String>planning_trace_id: Option<String>started_at_unix_ms: u64completed_at_unix_ms: u64latency_ms: u64status: i32status_message: Option<String>summary: Option<OperationTraceSummary>recall_explanation: Option<RecallExplanation>Implementations
Sourceimpl OperationTrace
impl OperationTrace
Sourcepub fn operation(&self) -> TraceOperationKind
pub fn operation(&self) -> TraceOperationKind
Returns the enum value of operation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operation(&mut self, value: TraceOperationKind)
pub fn set_operation(&mut self, value: TraceOperationKind)
Sets operation to the provided enum value.
Sourcepub fn tenant_id(&self) -> &str
pub fn tenant_id(&self) -> &str
Returns the value of tenant_id, or the default value if tenant_id is unset.
Sourcepub fn namespace(&self) -> &str
pub fn namespace(&self) -> &str
Returns the value of namespace, or the default value if namespace is unset.
Sourcepub fn principal(&self) -> &str
pub fn principal(&self) -> &str
Returns the value of principal, or the default value if principal is unset.
Sourcepub fn status(&self) -> TraceStatus
pub fn status(&self) -> TraceStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TraceStatus)
pub fn set_status(&mut self, value: TraceStatus)
Sets status to the provided enum value.
Sourcepub fn status_message(&self) -> &str
pub fn status_message(&self) -> &str
Returns the value of status_message, or the default value if status_message is unset.
Sourcepub fn backend(&self) -> &str
pub fn backend(&self) -> &str
Returns the value of backend, or the default value if backend is unset.
Sourcepub fn admission_class(&self) -> &str
pub fn admission_class(&self) -> &str
Returns the value of admission_class, or the default value if admission_class is unset.
Sourcepub fn store_span_id(&self) -> &str
pub fn store_span_id(&self) -> &str
Returns the value of store_span_id, or the default value if store_span_id is unset.
Sourcepub fn planning_trace_id(&self) -> &str
pub fn planning_trace_id(&self) -> &str
Returns the value of planning_trace_id, or the default value if planning_trace_id is unset.