pub struct RecallExplanation {
pub selected_channels: Vec<String>,
pub policy_notes: Vec<String>,
pub trace_id: Option<String>,
pub planning_trace: Option<RecallPlanningTrace>,
pub scorer_kind: i32,
pub scoring_profile: i32,
pub planning_profile: Option<String>,
pub policy_profile: i32,
}Fields
selected_channels: Vec<String>policy_notes: Vec<String>trace_id: Option<String>planning_trace: Option<RecallPlanningTrace>scorer_kind: i32scoring_profile: i32planning_profile: Option<String>policy_profile: i32Implementations
Sourceimpl RecallExplanation
impl RecallExplanation
Sourcepub fn trace_id(&self) -> &str
pub fn trace_id(&self) -> &str
Returns the value of trace_id, or the default value if trace_id is unset.
Sourcepub fn scorer_kind(&self) -> RecallScorerKind
pub fn scorer_kind(&self) -> RecallScorerKind
Returns the enum value of scorer_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_scorer_kind(&mut self, value: RecallScorerKind)
pub fn set_scorer_kind(&mut self, value: RecallScorerKind)
Sets scorer_kind to the provided enum value.
Sourcepub fn scoring_profile(&self) -> RecallScoringProfile
pub fn scoring_profile(&self) -> RecallScoringProfile
Returns the enum value of scoring_profile, or the default if the field is set to an invalid enum value.
Sourcepub fn set_scoring_profile(&mut self, value: RecallScoringProfile)
pub fn set_scoring_profile(&mut self, value: RecallScoringProfile)
Sets scoring_profile to the provided enum value.
Sourcepub fn planning_profile(&self) -> &str
pub fn planning_profile(&self) -> &str
Returns the value of planning_profile, or the default value if planning_profile is unset.
Sourcepub fn policy_profile(&self) -> RecallPolicyProfile
pub fn policy_profile(&self) -> RecallPolicyProfile
Returns the enum value of policy_profile, or the default if the field is set to an invalid enum value.
Sourcepub fn set_policy_profile(&mut self, value: RecallPolicyProfile)
pub fn set_policy_profile(&mut self, value: RecallPolicyProfile)
Sets policy_profile to the provided enum value.