pub struct RecallScoreBreakdown {
pub lexical: f32,
pub semantic: f32,
pub graph: f32,
pub temporal: f32,
pub policy: f32,
pub total: f32,
pub metadata: f32,
pub curation: f32,
pub episodic: f32,
pub salience: f32,
}Fields
lexical: f32semantic: f32graph: f32temporal: f32policy: f32total: f32metadata: f32curation: f32episodic: f32salience: f32Trait Implementations
Sourceimpl Clone for RecallScoreBreakdown
impl Clone for RecallScoreBreakdown
Sourcefn clone(&self) -> RecallScoreBreakdown
fn clone(&self) -> RecallScoreBreakdown
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecallScoreBreakdown
impl Debug for RecallScoreBreakdown
Sourceimpl Default for RecallScoreBreakdown
impl Default for RecallScoreBreakdown
Sourceimpl Message for RecallScoreBreakdown
impl Message for RecallScoreBreakdown
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RecallScoreBreakdown
impl PartialEq for RecallScoreBreakdown
Sourcefn eq(&self, other: &RecallScoreBreakdown) -> bool
fn eq(&self, other: &RecallScoreBreakdown) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RecallScoreBreakdown
impl StructuralPartialEq for RecallScoreBreakdown