pub struct RepairReply {
pub dry_run: bool,
pub scanned_records: u64,
pub scanned_idempotency_keys: u64,
pub removed_stale_idempotency_keys: u64,
pub rebuilt_missing_idempotency_keys: u64,
pub healthy_after: bool,
}Fields
dry_run: boolscanned_records: u64scanned_idempotency_keys: u64removed_stale_idempotency_keys: u64rebuilt_missing_idempotency_keys: u64healthy_after: boolTrait Implementations
Sourceimpl Clone for RepairReply
impl Clone for RepairReply
Sourcefn clone(&self) -> RepairReply
fn clone(&self) -> RepairReply
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepairReply
impl Debug for RepairReply
Sourceimpl Default for RepairReply
impl Default for RepairReply
Sourceimpl Hash for RepairReply
impl Hash for RepairReply
Sourceimpl Message for RepairReply
impl Message for RepairReply
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RepairReply
impl PartialEq for RepairReply
Sourcefn eq(&self, other: &RepairReply) -> bool
fn eq(&self, other: &RepairReply) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RepairReply
impl Eq for RepairReply
impl StructuralPartialEq for RepairReply