pub struct EngineTuningInfo {
pub recall_scorer_kind: i32,
pub recall_scoring_profile: i32,
pub embedding_provider_kind: i32,
pub embedding_dimensions: u64,
pub compaction_summarize_after_record_count: u64,
pub compaction_cold_archive_after_days: u32,
pub compaction_cold_archive_importance_threshold_per_mille: u32,
}Fields
recall_scorer_kind: i32recall_scoring_profile: i32embedding_provider_kind: i32embedding_dimensions: u64compaction_summarize_after_record_count: u64compaction_cold_archive_after_days: u32compaction_cold_archive_importance_threshold_per_mille: u32Implementations
Sourceimpl EngineTuningInfo
impl EngineTuningInfo
Sourcepub fn recall_scorer_kind(&self) -> RecallScorerKind
pub fn recall_scorer_kind(&self) -> RecallScorerKind
Returns the enum value of recall_scorer_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_recall_scorer_kind(&mut self, value: RecallScorerKind)
pub fn set_recall_scorer_kind(&mut self, value: RecallScorerKind)
Sets recall_scorer_kind to the provided enum value.
Sourcepub fn recall_scoring_profile(&self) -> RecallScoringProfile
pub fn recall_scoring_profile(&self) -> RecallScoringProfile
Returns the enum value of recall_scoring_profile, or the default if the field is set to an invalid enum value.
Sourcepub fn set_recall_scoring_profile(&mut self, value: RecallScoringProfile)
pub fn set_recall_scoring_profile(&mut self, value: RecallScoringProfile)
Sets recall_scoring_profile to the provided enum value.
Sourcepub fn embedding_provider_kind(&self) -> EmbeddingProviderKind
pub fn embedding_provider_kind(&self) -> EmbeddingProviderKind
Returns the enum value of embedding_provider_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_embedding_provider_kind(&mut self, value: EmbeddingProviderKind)
pub fn set_embedding_provider_kind(&mut self, value: EmbeddingProviderKind)
Sets embedding_provider_kind to the provided enum value.